/*
 * Copyright (c) 2020 Alex aka mailoman <alex@webz.asia>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *   @author Alex aka mailoman <alex@webz.asia>
 *   @copyright Copyright (c) 2020 Alex aka mailoman <alex@webz.asia>
 *   @since 14.01.2020
 *
 */

package fields

const (
	defaultTagName          = "conv"
	defaultOmitTagName      = "omit"
	defaultOmitEmptyTagName = "omitempty"
)

var (
	tagName          = defaultTagName
	omitTagName      = defaultOmitTagName
	omitEmptyTagName = defaultOmitEmptyTagName
)

// ConvertTagName returns special tag name
func ConvertTagName() string {
	return tagName
}

// OmitTagName returns omitting tag name
func OmitTagName() string {
	return omitTagName
}

// OmitEmptyTagName returns omitting empty field tag name
func OmitEmptyTagName() string {
	return omitEmptyTagName
}

// SetTagName sets special tag name
func SetTagName(value string) {
	tagName = value
}

// SetOmitTagName sets omitting tag name
func SetOmitTagName(value string) {
	omitTagName = value
}

// SetOmitEmptyTagName sets omitting empty field tag name
func SetOmitEmptyTagName(value string) {
	omitEmptyTagName = value
}

// SetDefaults resets all configured tag names to defaults
func SetDefaults() {
	SetTagName(defaultTagName)
	SetOmitTagName(defaultOmitTagName)
	SetOmitEmptyTagName(defaultOmitEmptyTagName)
}
